==> Paws-0.14.tar.gz: Paws-0.14/lib/Paws/CloudWatchLogs/DescribeDestinations.pm <==

package Paws::CloudWatchLogs::DescribeDestinations {
  use Moose;
  has DestinationNamePrefix => (is => 'ro', isa => 'Str');
  has limit => (is => 'ro', isa => 'Int');
  has nextToken => (is => 'ro', isa => 'Str');

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'DescribeDestinations');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::CloudWatchLogs::DescribeDestinationsResponse');
  class_has _result_key => (isa => 'Str', is => 'ro');
}
1;

### main pod documentation begin ###

=head1 NAME

Paws::CloudWatchLogs::DescribeDestinations - Arguments for method DescribeDestinations on Paws::CloudWatchLogs

=head1 DESCRIPTION

This class represents the parameters used for calling the method DescribeDestinations on the 
Amazon CloudWatch Logs service. Use the attributes of this class
as arguments to method DescribeDestinations.

You shouln't make instances of this class. Each attribute should be used as a named argument in the call to DescribeDestinations.

As an example:

  $service_obj->DescribeDestinations(Att1 => $value1, Att2 => $value2, ...);

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.

=head1 ATTRIBUTES

=head2 DestinationNamePrefix => Str

  

Will only return destinations that match the provided
destinationNamePrefix. If you don't specify a value, no prefix is
applied.










=head2 limit => Int

  

=head2 nextToken => Str

  



=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method DescribeDestinations in L<Paws::CloudWatchLogs>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut

==> Paws-0.16.tar.gz: Paws-0.16/lib/Paws/CloudWatchLogs/DescribeDestinations.pm <==

package Paws::CloudWatchLogs::DescribeDestinations;
  use Moose;
  has DestinationNamePrefix => (is => 'ro', isa => 'Str');
  has limit => (is => 'ro', isa => 'Int');
  has nextToken => (is => 'ro', isa => 'Str');

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'DescribeDestinations');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::CloudWatchLogs::DescribeDestinationsResponse');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::CloudWatchLogs::DescribeDestinations - Arguments for method DescribeDestinations on Paws::CloudWatchLogs

=head1 DESCRIPTION

This class represents the parameters used for calling the method DescribeDestinations on the 
Amazon CloudWatch Logs service. Use the attributes of this class
as arguments to method DescribeDestinations.

You shouln't make instances of this class. Each attribute should be used as a named argument in the call to DescribeDestinations.

As an example:

  $service_obj->DescribeDestinations(Att1 => $value1, Att2 => $value2, ...);

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.

=head1 ATTRIBUTES

=head2 DestinationNamePrefix => Str

  

Will only return destinations that match the provided
destinationNamePrefix. If you don't specify a value, no prefix is
applied.










=head2 limit => Int

  

=head2 nextToken => Str

  



=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method DescribeDestinations in L<Paws::CloudWatchLogs>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut
